<h3 align="center">

<img src="img/kanagawa@2x.png" width=200 />

🌊 kanagawa 🌊
</h3>

-----------------

Kanagawa theme implements a color palette defined in [kanagawa.nvim](https://github.com/rebelot/kanagawa.nvim). This color scheme is inspired by Katsushika Hokusai’s work,
especially, his famous "The Great Wave".

## How to use

In order to use this theme with `mkdocs_puml`, set `theme` config of the plugin as follows:

```yml
theme:
    light: kanagawa/fuji
    dark: kanagawa/wave
```

## Flavors

This theme has two flavors

- `fuji` for light mode
- `wave` for dark mode

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/classes/classes-fuji.svg)|![](examples/classes/classes-wave.svg)|

## Examples

Let's take a look at some diagrams other diagrams with `kanagawa` theme.

### Sequence

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/sequence/sequence-fuji.svg)|![](examples/sequence/sequence-wave.svg)|

### Activity

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/activity/activity-fuji.svg)|![](examples/activity/activity-wave.svg)|

### State

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/state/state-fuji.svg)|![](examples/state/state-wave.svg)|

### Entity

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/entity/entity-fuji.svg)|![](examples/entity/entity-wave.svg)|

### C4

|**kanagawa/fuji**|**kanagawa/wave**|
|:-------:|:--------:|
|![](examples/c4/c4-fuji.svg)|![](examples/c4/c4-wave.svg)|
